@@ -1,3 +1,4 @@
+// $Revision: 1.94 $
 // MASTER FILE. Use this file as base for translations.
 
 // Translated files should be sent to the mplayer-dev-eng mailing list or
@@ -8,11 +9,6 @@
 // ========================= MPlayer help ===========================
 
 #ifdef HELP_MP_DEFINE_STATIC
-static char* banner_text=
-"\n\n"
-"MPlayer " VERSION "(C) 2000-2003 Arpad Gereoffy (see DOCS)\n"
-"\n";
-
 static char help_text[]=
 "Usage:   mplayer [options] [url|path/]filename\n"
 "\n"
@@ -48,7 +44,7 @@ static char help_text[]=
 " p or SPACE       pause movie (press any key to continue)\n"
 " q or ESC         stop playing and quit program\n"
 " + or -           adjust audio delay by +/- 0.1 second\n"
-" o                cycle OSD mode:  none / seekbar / seekbar+timer\n"
+" o                cycle OSD mode:  none / seekbar / seekbar + timer\n"
 " * or /           increase or decrease PCM volume\n"
 " z or x           adjust subtitle delay by +/- 0.1 second\n"
 " r or t           adjust subtitle position up/down, also see -vop expand\n"
@@ -141,7 +137,7 @@ static char help_text[]=
 #define MSGTR_AOComment "AO: Comment: %s\n"
 #define MSGTR_Video_NoVideo "Video: no video\n"
 #define MSGTR_NotInitializeVOPorVO "\nFATAL: Could not initialize video filters (-vop) or video output (-vo).\n"
-#define MSGTR_Paused "\n================= PAUSED =================\r"
+#define MSGTR_Paused "\n  =====  PAUSE  =====\r" // no more than 23 characters (status line for audio files)
 #define MSGTR_PlaylistLoadUnable "\nUnable to load playlist %s.\n"
 #define MSGTR_Exit_SIGILL_RTCpuSel \
 "- MPlayer crashed by an 'Illegal Instruction'.\n"\
@@ -165,7 +161,6 @@ static char help_text[]=
 
 // mencoder.c:
 
-#define MSGTR_MEncoderCopyright "(C) 2000-2003 Arpad Gereoffy (see DOCS)\n"
 #define MSGTR_UsingPass3ControllFile "Using pass3 control file: %s\n"
 #define MSGTR_MissingFilename "\nFilename missing.\n\n"
 #define MSGTR_CannotOpenFile_Device "Cannot open file/device.\n"
