@@ -4,11 +4,6 @@
  ========================= MPlayer help =========================== */
 
 #ifdef HELP_MP_DEFINE_STATIC
-static char* banner_text=
-"\n\n"
-"MPlayer " VERSION "(C) 2000-2003 Arpad Gereoffy (. DOCS!)\n"
-"\n";
-
 static char help_text[]=
 ":   mplayer [] [URL|path/]filename\n"
 "\n"
@@ -37,10 +32,10 @@ static char help_text[]=
 " -framedrop         (  )\n"
 "\n"
 " : (    man,   input.conf)\n"
-" <-   ->       /  10 \n"
-" up  down      /   1 \n"
-" pgup or pgdown   /  10 \n"
-" <  >          /  playlist'\n"
+" <-   ->       ң/  10 \n"
+" up  down      ң/   1 \n"
+" pgup or pgdown   ң/  10 \n"
+" <  >          ң/  playlist'\n"
 " p        (  - )\n"
 " q  ESC          \n"
 " +  -             +/- 0.1 \n"
@@ -104,7 +99,7 @@ static char help_text[]=
 "  -   : -nobps  -ni  -mc 0  -forceidx\n"\
 "-   ( NFS/SMB, DVD, VCD  . .)\n"\
 "  -  -cache 8192.\n"\
-"-    -cache   -''[non-interleaved] AVI ?\n"\
+"-    -cache   -'ϣ'[non-interleaved] AVI ?\n"\
 "  -  -nocache.\n"\
 " DOCS/video.html  DOCS/sound.html    /.\n"\
 "   ,   DOCS/bugreports.html !\n\n"
@@ -147,7 +142,7 @@ static char help_text[]=
 #define MSGTR_Exit_SIGSEGV_SIGFPE \
 "- MPlayer  -   CPU/FPU/RAM.\n"\
 "   MPlayer  --enable-debug   'gdb' backtrace \n"\
-"  .  , . DOCS/bugreports.html#crash.b.\n"
+"  .  , . DOCS/bugreports.html#crash\n"
 #define MSGTR_Exit_SIGCRASH \
 "- MPlayer .    .\n"\
 "        MPlayer' __    __   \n"\
@@ -158,7 +153,6 @@ static char help_text[]=
 
 // mencoder.c:
 
-#define MSGTR_MEncoderCopyright "(C) 2000-2003 Arpad Gereoffy (. DOCS)\n"
 #define MSGTR_UsingPass3ControllFile "     3 : %s\n"
 #define MSGTR_MissingFilename "\n  .\n\n"
 #define MSGTR_CannotOpenFile_Device "   /.\n"
@@ -190,7 +184,7 @@ static char help_text[]=
 "                3: abr\n"\
 "                4: mtrh\n"\
 "\n"\
-" abr            \n"\
+" abr           Σ \n"\
 "\n"\
 " cbr            \n"\
 "                 CBR      ABR \n"\
@@ -207,7 +201,7 @@ static char help_text[]=
 "\n"\
 " mode=<0-3>    (-: )\n"\
 "                0: \n"\
-"                1:  [joint-stereo]\n"\
+"                1: Σ [joint-stereo]\n"\
 "                2: \n"\
 "                3: \n"\
 "\n"\
@@ -257,13 +251,13 @@ static char help_text[]=
 #define MSGTR_DVDopenOk "DVD  !\n"
 
 // demuxer.c, demux_*.c:
-#define MSGTR_AudioStreamRedefined "!    %d !\n"
-#define MSGTR_VideoStreamRedefined "!    %d !\n"
+#define MSGTR_AudioStreamRedefined "!    %d ̣!\n"
+#define MSGTR_VideoStreamRedefined "!    %d ̣!\n"
 #define MSGTR_TooManyAudioInBuffer "\nDEMUXER:   (%d  %d )    !\n"
 #define MSGTR_TooManyVideoInBuffer "\nDEMUXER:   (%d  %d )    !\n"
-#define MSGTR_MaybeNI "    '' /   ?\n" \
-                     " AVI    ''   -ni.\n"
-#define MSGTR_SwitchToNi "\n  '' AVI  -   -ni ...\n"
+#define MSGTR_MaybeNI "    'ϣ' /   ?\n" \
+                     " AVI    'ϣ'   -ni.\n"
+#define MSGTR_SwitchToNi "\n  'ϣ' AVI  -   -ni ...\n"
 #define MSGTR_Detected_XXX_FileFormat " %s  !\n"
 #define MSGTR_DetectedAudiofile "  .\n"
 #define MSGTR_NotSystemStream " MPEG System Stream ... ( Transport Stream?)\n"
@@ -291,8 +285,8 @@ static char help_text[]=
 #define MSGTR_MOVcomprhdr "MOV:   ()  !\n"
 #define MSGTR_MOVvariableFourCC "MOV: !   FOURCC!?\n"
 #define MSGTR_MOVtooManyTrk "MOV: !   !"
-#define MSGTR_FoundAudioStream "==>   : %d\n"
-#define MSGTR_FoundVideoStream "==>   : %d\n"
+#define MSGTR_FoundAudioStream "==> ۣ  : %d\n"
+#define MSGTR_FoundVideoStream "==> ۣ  : %d\n"
 #define MSGTR_DetectedTV " TV! ;-)\n"
 #define MSGTR_ErrorOpeningOGGDemuxer "   ogg [demuxer].\n"
 #define MSGTR_ASFSearchingForAudioStream "ASF:    (id:%d).\n"
@@ -335,9 +329,9 @@ static char help_text[]=
 #define MSGTR_OpeningAudioDecoder "  : [%s] %s\n"
 #define MSGTR_UninitVideoStr " : %s\n"
 #define MSGTR_UninitAudioStr " : %s\n"
-#define MSGTR_VDecoderInitFailed "   :(\n"
-#define MSGTR_ADecoderInitFailed "   :(\n"
-#define MSGTR_ADecoderPreinitFailed "   :(\n"
+#define MSGTR_VDecoderInitFailed "    :(\n"
+#define MSGTR_ADecoderInitFailed "    :(\n"
+#define MSGTR_ADecoderPreinitFailed "    :(\n"
 #define MSGTR_AllocatingBytesForInputBuffer "dec_audio:  %d (/)   \n"
 #define MSGTR_AllocatingBytesForOutputBuffer "dec_audio:  %d + %d = %d (/)   \n"
 
@@ -358,7 +352,7 @@ static char help_text[]=
 #define MSGTR_VoConfigRequest "VDec: vo config  - %d x %d ( csp: %s)\n"
 #define MSGTR_CouldNotFindColorspace "      -   -vop scale...\n"
 #define MSGTR_MovieAspectIsSet "Movie-Aspect - %.2f:1 -      .\n"
-#define MSGTR_MovieAspectUndefined "Movie-Aspect   -   .\n"
+#define MSGTR_MovieAspectUndefined "Movie-Aspect  ̣ -   .\n"
 
 
 // ====================== GUI messages/buttons ========================
@@ -399,7 +393,7 @@ static char help_text[]=
 // --- error messages ---
 #define MSGTR_NEMDB "Sorry,      ."
 #define MSGTR_NEMFMR "Sorry,      ."
-#define MSGTR_IDFGCVD "Sorry,     GUI   ."
+#define MSGTR_IDFGCVD "Sorry,  ۣ   GUI   ."
 #define MSGTR_NEEDLAVCFAME "Sorry,     -MPEG    DXR3/H+   .\n,  lavc  fame   DXR3/H+."
 
 
@@ -535,7 +529,7 @@ static char help_text[]=
 #define MSGTR_PREFERENCES_FontFactor " :"
 #define MSGTR_PREFERENCES_PostProcess " "
 #define MSGTR_PREFERENCES_AutoQuality " : "
-#define MSGTR_PREFERENCES_NI " '' AVI "
+#define MSGTR_PREFERENCES_NI " 'ϣ' AVI "
 #define MSGTR_PREFERENCES_IDX " ,   "
 #define MSGTR_PREFERENCES_VideoCodecFamily "  :"
 #define MSGTR_PREFERENCES_AudioCodecFamily "  :"
@@ -556,7 +550,7 @@ static char help_text[]=
 #define MSGTR_PREFERENCES_FontEncoding1 "Unicode"
 #define MSGTR_PREFERENCES_FontEncoding2 "  (ISO-8859-1)"
 #define MSGTR_PREFERENCES_FontEncoding3 "    (ISO-8859-15)"
-#define MSGTR_PREFERENCES_FontEncoding4 "/  (ISO-8859-2)"
+#define MSGTR_PREFERENCES_FontEncoding4 "/-  (ISO-8859-2)"
 #define MSGTR_PREFERENCES_FontEncoding5 ", Galician, ,  (ISO-8859-3)"
 #define MSGTR_PREFERENCES_FontEncoding6 "   (ISO-8859-4)"
 #define MSGTR_PREFERENCES_FontEncoding7 " (ISO-8859-5)"
@@ -568,7 +562,7 @@ static char help_text[]=
 #define MSGTR_PREFERENCES_FontEncoding13 "  (ISO-8859-8)"
 #define MSGTR_PREFERENCES_FontEncoding14 " (KOI8-R)"
 #define MSGTR_PREFERENCES_FontEncoding15 ",  (KOI8-U/RU)"
-#define MSGTR_PREFERENCES_FontEncoding16 "   (CP936)"
+#define MSGTR_PREFERENCES_FontEncoding16 "ݣ   (CP936)"
 #define MSGTR_PREFERENCES_FontEncoding17 "   (BIG5)"
 #define MSGTR_PREFERENCES_FontEncoding18 "  (SHIFT-JIS)"
 #define MSGTR_PREFERENCES_FontEncoding19 "  (CP949)"
@@ -579,13 +573,14 @@ static char help_text[]=
 #define MSGTR_PREFERENCES_FontPropHeight "  "
 #define MSGTR_PREFERENCES_FontPropDiagonal "  "
 #define MSGTR_PREFERENCES_FontEncoding ":"
-#define MSGTR_PREFERENCES_FontBlur ":"
+#define MSGTR_PREFERENCES_FontBlur "ޣ:"
 #define MSGTR_PREFERENCES_FontOutLine ":"
 #define MSGTR_PREFERENCES_FontTextScale " :"
 #define MSGTR_PREFERENCES_FontOSDScale " OSD:"
 #define MSGTR_PREFERENCES_Cache " /"
 #define MSGTR_PREFERENCES_CacheSize " : "
 #define MSGTR_PREFERENCES_LoadFullscreen "   "
+#define MSGTR_PREFERENCES_SaveWinPos "  "
 #define MSGTR_PREFERENCES_XSCREENSAVER " XScreenSaver"
 #define MSGTR_PREFERENCES_PlayBar " playbar"
 #define MSGTR_PREFERENCES_AutoSync "AutoSync /"
