@@ -1,7 +1,7 @@
 /*
   Video 4 Linux input
 
-  (C) Alex Beregszaszi <alex@naxine.org>
+  (C) Alex Beregszaszi <alex@fsn.hu>
   
   Some ideas are based on xawtv/libng's grab-v4l.c written by
     Gerd Knorr <kraxel@bytesex.org>
@@ -45,7 +45,7 @@
 static tvi_info_t info = {
 	"Video 4 Linux input",
 	"v4l",
-	"Alex Beregszaszi <alex@naxine.org>",
+	"Alex Beregszaszi <alex@fsn.hu>",
 	"under development"
 };
 
@@ -76,7 +76,7 @@ typedef struct {
     int				width;
     int				height;
     int				bytesperline;
-    int				fps;
+    float			fps;
 
     struct video_mbuf		mbuf;
     unsigned char               *mmap;
@@ -918,7 +918,7 @@ static int control(priv_t *priv, int cmd, void *arg)
 	    control(priv, TVI_CONTROL_VID_SET_PICTURE, 0);
 	    return(TVI_CONTROL_TRUE);
 	case TVI_CONTROL_VID_GET_FPS:
-	    (int)*(void **)arg=priv->fps;
+	    *(float *)arg=priv->fps;
 	    return(TVI_CONTROL_TRUE);
 
 	/* ========== TUNER controls =========== */
