@@ -115,8 +115,10 @@ uint8_t   multi_idx=0; /* active buffer */
 
 /* Linux Video Overlay */
 static const char *lvo_name = NULL;
+static int lvo_opened = 0;
 #ifdef CONFIG_VIDIX
 static const char *vidix_name = NULL;
+static int vidix_opened = 0;
 #endif
 
 #define HAS_DGA()  (win.idx == -1)
@@ -150,9 +152,9 @@ static char * vbeErrToStr(int err)
 static void vesa_term( void )
 {
   int err;
-  if(lvo_name) vlvo_term();
+  if(lvo_opened) { vlvo_term();  lvo_opened = 0; }
 #ifdef CONFIG_VIDIX
-  else if(vidix_name) vidix_term();
+  else if(vidix_opened) { vidix_term();  vidix_opened = 0; }
 #endif
   if(init_state) if((err=vbeRestoreState(init_state)) != VBE_OK) PRINT_VBE_ERR("vbeRestoreState",err);
   init_state=NULL;
@@ -436,10 +438,6 @@ static uint32_t parseSubDevice(const char *sd)
 {
    uint32_t flags;
    flags = 0;
-   lvo_name = NULL;
-#ifdef CONFIG_VIDIX
-   vidix_name = NULL;
-#endif
    if(strcmp(sd,"nodga") == 0) { flags |= SUBDEV_NODGA; flags &= ~(SUBDEV_FORCEDGA); }
    else
    if(strcmp(sd,"dga") == 0)   { flags &= ~(SUBDEV_NODGA); flags |= SUBDEV_FORCEDGA; }
@@ -939,11 +937,11 @@ config(uint32_t width, uint32_t height, uint32_t d_width, uint32_t d_height, uin
 		  if(vlvo_init(width,height,x_offset,y_offset,dstW,dstH,format,dstBpp) != 0)
 		  {
 		    printf("vo_vesa: Can't initialize Linux Video Overlay\n");
-		    lvo_name = NULL;
 		    vesa_term();
 		    return -1;
 		  }
 		  else printf("vo_vesa: Using video overlay: %s\n",lvo_name);
+		  lvo_opened = 1;
 		}
 #ifdef CONFIG_VIDIX
 		else
@@ -954,12 +952,12 @@ config(uint32_t width, uint32_t height, uint32_t d_width, uint32_t d_height, uin
 				video_mode_info.XResolution,video_mode_info.YResolution) != 0)
 		  {
 		    printf("vo_vesa: Can't initialize VIDIX driver\n");
-		    vidix_name = NULL;
 		    vesa_term();
 		    return -1;
 		  }
 		  else printf("vo_vesa: Using VIDIX\n");
 		  vidix_start();
+		  vidix_opened = 1;
 		}
 #endif
 	}
@@ -985,11 +983,12 @@ config(uint32_t width, uint32_t height, uint32_t d_width, uint32_t d_height, uin
 	else
 	{
             clear_screen();	/* Clear screen for stupid BIOSes */
-	    if(verbose>1) paintBkGnd();
+	    if(verbose>1)
 	    {
 	        int x;
 	        x = (video_mode_info.XResolution/video_mode_info.XCharSize)/2-strlen(title)/2;
 	        if(x < 0) x = 0;
+	        paintBkGnd();
 	        vbeWriteString(x,0,7,title);
 	    }
 	}
@@ -1021,6 +1020,10 @@ static uint32_t preinit(const char *arg)
   if(verbose > 2)
         printf("vo_vesa: subdevice %s is being initialized\n",arg);
   subdev_flags = 0;
+  lvo_name = NULL;
+#ifdef CONFIG_VIDIX
+  vidix_name = NULL;
+#endif
   if(arg) subdev_flags = parseSubDevice(arg);
   if(lvo_name) pre_init_err = vlvo_preinit(lvo_name);
 #ifdef CONFIG_VIDIX
