@@ -27,11 +27,6 @@
 #include "mp_msg.h"
 #include "help_mp.h"
 
-static char* banner_text=
-"\n\n"
-"MEncoder " VERSION MSGTR_MEncoderCopyright
-"\n";
-
 #include "cpudetect.h"
 
 #include "codec-cfg.h"
@@ -362,7 +357,7 @@ unsigned int timer_start;
 
   mp_msg_init();
   mp_msg_set_level(MSGL_STATUS);
-  mp_msg(MSGT_CPLAYER,MSGL_INFO,"%s",banner_text);
+  mp_msg(MSGT_CPLAYER,MSGL_INFO, "MEncoder " VERSION " (C) 2000-2003 MPlayer Team\n\n");
 
   /* Test for cpu capabilities (and corresponding OS support) for optimizing */
   GetCpuCaps(&gCpuCaps);
@@ -745,13 +740,13 @@ case ACODEC_COPY:
     break;
 case ACODEC_PCM:
     printf("CBR PCM audio selected\n");
-    mux_a->h.dwSampleSize=2*sh_audio->channels;
     mux_a->h.dwScale=1;
     mux_a->h.dwRate=force_srate?force_srate:sh_audio->samplerate;
     mux_a->wf=malloc(sizeof(WAVEFORMATEX));
-    mux_a->wf->nBlockAlign=mux_a->h.dwSampleSize;
     mux_a->wf->wFormatTag=0x1; // PCM
     mux_a->wf->nChannels=audio_output_channels?audio_output_channels:sh_audio->channels;
+    mux_a->h.dwSampleSize=2*mux_a->wf->nChannels;
+    mux_a->wf->nBlockAlign=mux_a->h.dwSampleSize;
     mux_a->wf->nSamplesPerSec=mux_a->h.dwRate;
     mux_a->wf->nAvgBytesPerSec=mux_a->h.dwSampleSize*mux_a->wf->nSamplesPerSec;
     mux_a->wf->wBitsPerSample=16;
